You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@mahout.apache.org by "Sean Owen (JIRA)" <ji...@apache.org> on 2009/08/05 18:18:14 UTC
[jira] Updated: (MAHOUT-158) Replace all ID values with long
[ https://issues.apache.org/jira/browse/MAHOUT-158?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel ]
Sean Owen updated MAHOUT-158:
-----------------------------
Attachment: MAHOUT-158.patch
Preliminary patch for review for anyone that is curious. Also epic -- core changes only in this one so far! In my realistic-ish test case, required heap size went down about 25% (less than expected...) and speed increased by about 30%.
> Replace all ID values with long
> -------------------------------
>
> Key: MAHOUT-158
> URL: https://issues.apache.org/jira/browse/MAHOUT-158
> Project: Mahout
> Issue Type: Improvement
> Components: Clustering
> Affects Versions: 0.2
> Reporter: Sean Owen
> Assignee: Sean Owen
> Fix For: 0.2
>
> Attachments: MAHOUT-158.patch
>
>
> As mentioned on mailing list, I am tracking this as a possible change for evaluation. The idea is to save more memory / CPU by avoiding the Object overhead of tens of millions of ID objects by using long IDs instead.
--
This message is automatically generated by JIRA.
-
You can reply to this email to add a comment to the issue online.